@@ -331,18 +331,18 @@ C2=do.call(cbind,C2_d)
 C22=addtomatrix(C2,d,t,k)
 F11=as(C22,"sparseMatrix")+as(diag(rep((1/phi1),d)),"sparseMatrix")
 F22=DD+as(diag(rep((1/phi2),D)),"sparseMatrix")
-Fuu=as(rBind(cBind(F11,as(t(as(D2,"matrix")),"sparseMatrix")),cBind(D2,F22)),"sparseMatrix")
+Fuu=as(rbind(cbind(F11,as(t(as(D2,"matrix")),"sparseMatrix")),cbind(D2,F22)),"sparseMatrix")
 Fuui=as(solve(Fuu),"sparseMatrix")
 int=as(solve(F22),"sparseMatrix")
-Fuubb=rBind(as(t(as(B2,"matrix")),"sparseMatrix"),as(t(as(B,"matrix")),"sparseMatrix"))
+Fuubb=rbind(as(t(as(B2,"matrix")),"sparseMatrix"),as(t(as(B,"matrix")),"sparseMatrix"))
 Fbb=as(solve(A-t(as(Fuubb,"matrix"))%*%Fuui%*%(Fuubb)),"sparseMatrix")
 Fub=-1*Fbb%*%t(as(Fuubb,"matrix"))%*%Fuui
 Fu1u1=solve(F11-t(as(D2,"matrix"))%*%int%*%D2)
 Fu1u2=-1*Fu1u1%*%t(as(D2,"matrix"))%*%int
 Fu2u2=int+int%*%D2%*%Fu1u1%*%t(as(D2,"matrix"))%*%int
-Fiuu=rBind(cBind(Fu1u1,Fu1u2),cBind(t(as(Fu1u2,"matrix")),Fu2u2))
+Fiuu=rbind(cbind(Fu1u1,Fu1u2),cbind(t(as(Fu1u2,"matrix")),Fu2u2))
 Fuu=Fiuu+Fiuu%*%Fuubb%*%Fbb%*%t(as(Fuubb,"matrix"))%*%Fiuu
-F=rBind(cBind(Fbb,(Fub)),cBind(t(as(Fub,"matrix")),Fuu))
+F=rbind(cbind(Fbb,(Fub)),cbind(t(as(Fub,"matrix")),Fuu))
 S_u11=matrix(t(S_u1),d*(k-1),1)
 S_u22=matrix(t(S_u2),D*(k-1),1)
 S=rbind(S_beta,rbind(S_u11,S_u22))
@@ -1026,7 +1026,7 @@ for (i in 1:d){
 		pro[[jj]]=as(t(cbind(matrix(0,(k-1),(j-1)*(k-1)),sigmap[[jj]],matrix(0,(k-1),(t-j)*(k-1)))),"sparseMatrix")
 		pro22[[j]]=as(sigmapMM[[jj]]%*%X[[jj]],"sparseMatrix")
 		jj=jj+1}
-		pro2[[i]]=do.call(rBind,pro22)}
+		pro2[[i]]=do.call(rbind,pro22)}
 
 G1=list()
 G11=list()
